@@ -47,7 +47,7 @@ See --help for options.
             '-a', '--with-all-services',
             dest='withAll',
             action='store_true',
-            help='install software needed for every kind of service (equivalent to --with-dav --with-git --with-mercurial --with-subversion --with-trac)'
+            help='install software needed for every kind of service (equivalent to --with-dav --with-mercurial --with-subversion --with-trac)'
         )
         self.parser.add_option(
             '--with-dav',
@@ -59,7 +59,7 @@ See --help for options.
             '--with-git',
             dest='withGit',
             action='store_true',
-            help='install software needed for Git services'
+            help='this option currently has no affect'
         )
         self.parser.add_option(
             '--with-mercurial',
@@ -196,9 +196,6 @@ class KForgeInstaller(object):
         # DAV
         if self.options.withDav or self.options.withSvn or self.options.withAll:
             self.installDav()
-        # Git
-        if self.options.withGit or self.options.withAll:
-            self.installGit()
         # Mercurial
         if self.options.withMercurial or self.options.withAll:
             self.installMercurial()
@@ -207,7 +204,7 @@ class KForgeInstaller(object):
             self.installSubversion()
 
     def installTrac(self):
-        self.pipInstall('trac==0.12.5')
+        self.pipInstall('trac==1.0.1')
         if not self.options.isQuiet:
             print "Trac Python package installed OK"
 
@@ -216,12 +213,6 @@ class KForgeInstaller(object):
         if not self.options.isQuiet:
             print "DAV WSGI Python package installed OK"
 
-    def installGit(self):
-        # Trac Git plugin.
-        self.pipInstall('https://trac-hacks.org/svn/gitplugin/0.12/')
-        if not self.options.isQuiet:
-            print "Trac Git Python package installed OK"
-
     def installMercurial(self):
         # Trac Mercurial plugin.
         self.pipInstall('http://mercurial.selenic.com/release/mercurial-2.5.2.tar.gz')
@@ -231,8 +222,8 @@ class KForgeInstaller(object):
         # Since 'pip install' doesn't really work with this URL...
         #    <https://hg.edgewall.org/trac/mercurial-plugin#0.12>
         # ... so we have to do take these steps instead:
-        hgUrl = 'https://hg.edgewall.org/trac/mercurial-plugin#0.12'
-        hgPath = self.join(self.path, 'src-trac-mercurial-plugin-0.12')
+        hgUrl = 'https://hg.edgewall.org/trac/mercurial-plugin#1.0'
+        hgPath = self.join(self.path, 'src-trac-mercurial-plugin-1.0')
         try:
             self.runCmd(['hg', 'clone', hgUrl, hgPath])
             self.pipInstall(hgPath)
