@@ -5,12 +5,15 @@ import tempfile
 import shutil
 import os
 
+import json, os
+
 def suite():
     suites = [
-        unittest.makeSuite(TestKForgeInstallerBasics),
-        unittest.makeSuite(TestKForgeInstallerCore),
-        unittest.makeSuite(TestKForgeInstallerDatabases),
-        unittest.makeSuite(TestKForgeInstallerServices),
+#        unittest.makeSuite(TestKForgeInstallerBasics),
+        unittest.makeSuite(TestKForgeInstallerCoreDev),
+#        unittest.makeSuite(TestKForgeInstallerCoreStable),
+#        unittest.makeSuite(TestKForgeInstallerDatabases),
+#        unittest.makeSuite(TestKForgeInstallerServices),
     ]
     return unittest.TestSuite(suites)
 
@@ -95,38 +98,54 @@ class TestKForgeInstallerBasics(KForgeInstallerTestCase):
         self.failUnlessRaises(Exception, self.installer.pipInstall, 'urllib33333')
 
 
-class TestKForgeInstallerCore(KForgeInstallerTestCase):
+class KForgeInstallerCoreTestCase(KForgeInstallerTestCase):
 
     def setUp(self):
-        super(TestKForgeInstallerCore, self).setUp()
+        super(KForgeInstallerCoreTestCase, self).setUp()
         # Create virtualenv.
         self.installer.createVirtualenv()
 
+    def getVersion(self, level, system):
+        v = json.loads(open(os.path.expanduser('~/.asfversions')).read())
+        return v[level][system]
+
+    
+class TestKForgeInstallerCoreStable(KForgeInstallerCoreTestCase):
+
     def testInstallKForge(self):
         self.failIf(self.installer.canPythonImport('kforge'))
         self.installer.installKForge()
         self.failUnless(self.installer.canPythonImport('kforge'))
-    
-    def testInstallKForgeDev(self):
-        kforgeUrl = 'http://appropriatesoftware.net/provide/docs/kforge-0.20.tar.gz'
-        dmUrl = 'http://appropriatesoftware.net/provide/docs/domainmodel-0.15.tar.gz'
-        self.failIf(self.installer.canPythonImport('kforge'))
-        self.installer.options.kforge_requirement_or_url = kforgeUrl
-        self.failUnlessRaises(Exception, self.installer.installKForge)
-        self.installer.options.dm_requirement_or_url = dmUrl
-        self.installer.installKForge()
-        self.failUnless(self.installer.canPythonImport('kforge'))
-    
+   
     def testInstallDomainModel(self): 
         self.failIf(self.installer.canPythonImport('dm'))
         self.installer.installDomainModel()
         self.failIf(self.installer.canPythonImport('dm'))
-        dmUrl = 'http://appropriatesoftware.net/provide/docs/domainmodel-0.15.tar.gz'
+        dmUrl = 'http://appropriatesoftware.net/provide/docs/domainmodel-%s.tar.gz' % self.getVersion('stable', 'domainmodel')
         self.installer.options.dm_requirement_or_url = dmUrl
         self.installer.installDomainModel()
         self.failUnless(self.installer.canPythonImport('dm'))
 
 
+class TestKForgeInstallerCoreDev(KForgeInstallerCoreTestCase):
+
+    def testInstallKForgeDev(self):
+        # Test the installer can install the development versions.
+        # URLs need to be maintained as the latest development versions.
+        kforgeUrl = 'http://appropriatesoftware.net/provide/docs/kforge-%s.tar.gz' % self.getVersion('development', 'kforge')
+        dmUrl = 'http://appropriatesoftware.net/provide/docs/domainmodel-%s.tar.gz' % self.getVersion('development', 'domainmodel')
+        self.failIf(self.installer.canPythonImport('kforge'))
+        # Set path to development kforge distribution.
+        self.installer.options.kforge_requirement_or_url = kforgeUrl
+        # Check the installer fails (domainmodel distribution not yet set).
+        self.failUnlessRaises(Exception, self.installer.installKForge)
+        # Set path to development domainmodel distribution.
+        self.installer.options.dm_requirement_or_url = dmUrl
+        # Check the installer succeedes.
+        self.installer.installKForge()
+        self.failUnless(self.installer.canPythonImport('kforge'))
+    
+
 class TestKForgeInstallerDatabases(KForgeInstallerTestCase):
 
     def setUp(self):
@@ -169,12 +188,10 @@ class TestKForgeInstallerServices(KForgeInstallerTestCase):
         self.installer.options.withMercurial = True
         self.installer.options.withSvn = True
         self.failIf(self.installer.canPythonImport('trac'))
-        self.failIf(self.installer.canPythonImport('tracext.git'))
         self.failIf(self.installer.canPythonImport('tracext.hg'))
         self.failIf(self.installer.canPythonImport('svn'))
         self.installer.installServices()
         self.failUnless(self.installer.canPythonImport('trac'))
-        self.failUnless(self.installer.canPythonImport('tracext.git'))
         self.failUnless(self.installer.canPythonImport('tracext.hg'))
         self.failUnless(self.installer.canPythonImport('svn'))
 
@@ -195,12 +212,10 @@ class TestKForgeInstallerServices(KForgeInstallerTestCase):
     def testInstallTrac(self):
         self.installer.options.withTrac = True
         self.failIf(self.installer.canPythonImport('trac'))
-        self.failIf(self.installer.canPythonImport('tracext.git'))
         self.failIf(self.installer.canPythonImport('tracext.hg'))
         self.failIf(self.installer.canPythonImport('svn'))
         self.installer.installServices()
         self.failUnless(self.installer.canPythonImport('trac'))
-        self.failIf(self.installer.canPythonImport('tracext.git'))
         self.failIf(self.installer.canPythonImport('tracext.hg'))
         self.failIf(self.installer.canPythonImport('svn'))
 
@@ -210,7 +225,6 @@ class TestKForgeInstallerServices(KForgeInstallerTestCase):
         self.failUnless(self.installer.canPythonImport('mercurial'))
         self.failUnless(self.installer.canPythonImport('wsgidav'))
         self.failUnless(self.installer.canPythonImport('trac'))
-        self.failUnless(self.installer.canPythonImport('tracext.git'))
         self.failUnless(self.installer.canPythonImport('tracext.hg'))
         self.failUnless(self.installer.canPythonImport('svn'))
 
