@@ -31,7 +31,9 @@ class TestRunner(object):
 
     def __init__(self):
         self.parseInput()
-        self.runTestSuite()
+        result = self.runTestSuite()
+        if not result.wasSuccessful():
+            sys.exit(1)
 
     def parseInput(self):
         self.parser = OptionParser(self.usage)
